@@ -30,7 +30,7 @@ class MoleculeType(LowercaseStrEnum):
     PROTEIN = auto()
     RNA = auto()
     DNA = auto()
-    CARBOH = auto()
+    CARBOHYDRATE = auto()
 
 
 NEF_CHAIN_CODE = "chain_code"
@@ -404,22 +404,34 @@ def sequence_residues_to_sequence_3let(
     ]
 
 
-def frame_to_chains(sequence_frame: Saveframe) -> List[str]:
+def chains_from_frames(
+    sequence_frame_or_frames: Union[Saveframe, List[Saveframe]]
+) -> List[str]:
     """
      a nef molecular systems list the chains found
 
     :param sequence_frames: a nef molecular system save frame
     :return: a list of chain_codes
     """
+    if isinstance(sequence_frame_or_frames, Saveframe):
+        sequence_frames = [
+            sequence_frame_or_frames,
+        ]
+    else:
+        sequence_frames = sequence_frame_or_frames
 
     chains = set()
-    for loop in sequence_frame.loop_dict.values():
-        for row in loop_row_namespace_iter(loop):
-            chains.add(row.chain_code)
+    for sequence_frame in sequence_frames:
+        sequences = sequences_from_frames(sequence_frame)
+        for residue in sequences:
+            chains.add(residue.chain_code)
 
     if NEF_UNKNOWN in chains:
         chains.remove(NEF_UNKNOWN)
 
+    if None in chains:
+        chains.remove(None)
+
     chains = sorted(chains)
 
     return chains
@@ -507,16 +519,16 @@ def sequence_from_entry(entry) -> List[SequenceResidue]:
         frames = entry.get_saveframes_by_category("nef_molecular_system")
 
         if frames:
-            result = sequence_from_frame(frames[0])
+            result = sequences_from_frames(frames[0])
     return result
 
 
-def sequence_from_frame(
-    frame: Saveframe, chain_codes_to_select: Union[str, List[str]] = ANY_CHAIN
+def sequences_from_frames(
+    frame_or_frames: Union[Saveframe, List[Saveframe]],
+    chain_codes_to_select: Union[str, List[str]] = ANY_CHAIN,
 ) -> List[SequenceResidue]:
     """
-    read sequences from a nef molecular system save frame
-    can raise Exceptions
+    read sequences from a nef save frame with the maximal information content about the residues
 
     :param frame: the save frame to read residues from, must have category nef molecular system
     :param chain_code_to_select: the chain codes to select this can be either a string or list of strings,
@@ -524,6 +536,14 @@ def sequence_from_frame(
     :return: a list of parsed residues and chains, in the order they were read
     """
 
+    # TODO: check chain code for validity
+    if chain_codes_to_select is not ANY_CHAIN and isinstance(
+        chain_codes_to_select, str
+    ):
+        chain_codes_to_select = [
+            chain_codes_to_select,
+        ]
+
     if chain_codes_to_select is not ANY_CHAIN and isinstance(
         chain_codes_to_select, str
     ):
@@ -535,55 +555,242 @@ def sequence_from_frame(
     elif chain_codes_to_select is not ANY_CHAIN:
         chain_codes_to_select = set(chain_codes_to_select)
 
+    if isinstance(frame_or_frames, Saveframe):
+        frame_or_frames = [
+            frame_or_frames,
+        ]
+
     residues = OrderedSet()
+    for frame in frame_or_frames:
+        for loop in frame.loops:
+            residues.update(_parse_loops_residues(loop, chain_codes_to_select))
 
-    if frame.category != "nef_molecular_system":
-        raise Exception(
-            f"sequences can only be read from nef molecular system frames, the category of the provided frame "
-            f"was {frame.category}"
-        )
+    return select_best_residues_by_info_content(residues)
 
-    loop = frame.loops[0]
 
-    chain_code_index = loop.tag_index("chain_code")
-    sequence_code_index = loop.tag_index("sequence_code")
-    residue_name_index = loop.tag_index("residue_name")
-    linking_index = loop.tag_index("linking")
-    residue_variant_index = loop.tag_index("residue_variant")
+def select_best_residues_by_info_content(residues):
+    """
+    given a list of residues select the best residue definition for each chain code and sequence code
+    this removes formally unassigned residues [contain # or @ in sequence_code or chain_code] and favours a residue
+    with a residue name, the priority is then cis peptide > residue variants > linking though this shouldn't have an
+    effect unless there are errors in the definition of a molecular system
 
-    for line in loop:
-        chain_code = line[chain_code_index]
-        if chain_codes_to_select is ANY_CHAIN or chain_code in chain_codes_to_select:
-            sequence_code = line[sequence_code_index]
-            sequence_code = (
-                int(sequence_code) if is_int(sequence_code) else sequence_code
+    note if there are multiple residues with the same residue name they are both added...
+
+    :param residues: a list of residues
+
+    :return: a list of residues with the best description possible
+    """
+    residues = _filter_partially_or_unassigned_residues(residues)
+
+    residues_by_chain_code_sequence_code = {}
+    for residue in residues:
+        key = residue.chain_code, residue.sequence_code
+        residues_by_chain_code_sequence_code.setdefault(key, []).append(residue)
+
+    new_residues = []
+    for i, equivalent_residues in enumerate(
+        residues_by_chain_code_sequence_code.values()
+    ):
+
+        residues_and_scores = {}
+        score = 0
+        for equivalent_residue in equivalent_residues:
+            # somewhat arbitrary scoring system to pick the best residue
+            if equivalent_residue.residue_name not in (None, UNUSED):
+                score += 100000
+            if equivalent_residue.is_cis not in (None, UNUSED):
+                score += 10000
+            if equivalent_residue.variants not in (None, UNUSED):
+                score += 1000
+            if equivalent_residue.linking not in (None, UNUSED):
+                score += 100
+            residues_and_scores[score] = equivalent_residue
+
+        equivalent_residues = [
+            residues_and_scores[score] for score in sorted(residues_and_scores)
+        ]
+
+        new_equivalent_residues = []
+        if len(equivalent_residues) > 1:
+
+            seen_residue_names = set()
+            for equivalent_residue in equivalent_residues:
+                if equivalent_residue.residue_name not in (None, UNUSED):
+                    if equivalent_residue.residue_name not in seen_residue_names:
+                        new_equivalent_residues.append(equivalent_residue)
+                        seen_residue_names.add(equivalent_residue.residue_name)
+
+            if new_equivalent_residues:
+                new_equivalent_residues = [
+                    equivalent_residues[0],
+                ]
+        else:
+            new_equivalent_residues = [
+                equivalent_residues[0],
+            ]
+
+        new_residues.extend(new_equivalent_residues)
+    return new_residues
+
+
+def _filter_partially_or_unassigned_residues(residues):
+
+    result = []
+    for residue in residues:
+        if residue.chain_code in (None, UNUSED):
+            continue
+        if residue.sequence_code in (None, UNUSED):
+            continue
+        if isinstance(residue.chain_code, str) and residue.chain_code[0] in ("#", "@"):
+            continue
+        if isinstance(residue.sequence_code, str) and residue.sequence_code[0] in (
+            "#",
+            "@",
+        ):
+            continue
+        result.append(residue)
+    return result
+
+
+def _parse_loops_residues(loop, chain_codes_to_select):
+
+    offsets = [f"_{index}" for index in range(1, 16)]
+    offsets.insert(0, "")
+    index_sets = []
+    for offset in offsets:
+        if offset == "":
+            linking_tag = f"linking{offset}"
+            linking_index = (
+                loop.tag_index(linking_tag) if linking_tag in loop.tags else None
             )
-            residue_name = line[residue_name_index]
-            linking = (
-                Linking[line[linking_index].upper()]
-                if line[linking_index] != NEF_UNKNOWN
+
+            residue_variant_tag = f"residue_variant{offset}"
+            residue_variant_index = (
+                loop.tag_index(residue_variant_tag)
+                if residue_variant_tag in loop.tags
                 else None
             )
-            residue_variants = line[residue_variant_index].split(",")
-            residue_variants = (
-                ()
-                if residue_variants
-                == [
-                    UNUSED,
-                ]
-                else tuple(residue_variants)
+
+            cis_peptide_tag = f"cis_peptide{offset}"
+            cis_peptide_index = (
+                loop.tag_index(cis_peptide_tag)
+                if cis_peptide_tag in loop.tags
+                else None
             )
 
+        chain_code_tag = f"chain_code{offset}"
+        chain_code_index = (
+            loop.tag_index(chain_code_tag) if chain_code_tag in loop.tags else None
+        )
+
+        sequence_code_tag = f"sequence_code{offset}"
+        sequence_code_index = (
+            loop.tag_index(sequence_code_tag)
+            if sequence_code_tag in loop.tags
+            else None
+        )
+
+        residue_name_tag = f"residue_name{offset}"
+        residue_name_index = (
+            loop.tag_index(residue_name_tag) if residue_name_tag in loop.tags else None
+        )
+
+        if chain_code_index is None and sequence_code_index is None:
+            continue
+
+        index_set = {
+            "chain_code_index": chain_code_index,
+            "sequence_code_index": sequence_code_index,
+            "residue_name_index": residue_name_index,
+            "linking_index": linking_index,
+            "residue_variant_index": residue_variant_index,
+            "cis_peptide_index": cis_peptide_index,
+        }
+
+        index_sets.append(index_set)
+
+    residues = []
+    for line in loop:
+
+        for index_set in index_sets:
+            chain_code_index = index_set["chain_code_index"]
+            sequence_code_index = index_set["sequence_code_index"]
+            residue_name_index = index_set["residue_name_index"]
+            linking_index = index_set["linking_index"]
+            residue_variant_index = index_set["residue_variant_index"]
+            cis_peptide_index = index_set["cis_peptide_index"]
+
+            if chain_code_index is not None:
+                chain_code = line[chain_code_index]
+                if chain_code == UNUSED:
+                    continue
+
+                if not (
+                    chain_codes_to_select is ANY_CHAIN
+                    or chain_code in chain_codes_to_select
+                ):
+                    continue
+            else:
+                continue
+
+            if sequence_code_index is not None:
+                sequence_code = line[sequence_code_index]
+                sequence_code = (
+                    int(sequence_code) if is_int(sequence_code) else sequence_code
+                )
+            else:
+                sequence_code = None
+
+            residue_name = line[residue_name_index] if residue_name_index else None
+
+            if linking_index is not None:
+                linking = (
+                    Linking[line[linking_index].upper()]
+                    if line[linking_index] != NEF_UNKNOWN
+                    else None
+                )
+            else:
+                linking = None
+
+            if cis_peptide_index is not None:
+                cis_peptide = line[cis_peptide_index]
+                if cis_peptide == UNUSED:
+                    cis_peptide = False
+                elif cis_peptide.lower() == "true":
+                    cis_peptide = True
+                elif cis_peptide.lower() == "false":
+                    cis_peptide = False
+                else:
+                    cis_peptide = False
+            else:
+                cis_peptide = False
+
+            if residue_variant_index is not None:
+                residue_variants = line[residue_variant_index].split(",")
+                residue_variants = (
+                    ()
+                    if residue_variants
+                    == [
+                        UNUSED,
+                    ]
+                    else tuple(residue_variants)
+                )
+            else:
+                residue_variants = ()
+
             residue = SequenceResidue(
                 chain_code=chain_code,
                 sequence_code=sequence_code,
                 residue_name=residue_name,
                 linking=linking,
+                is_cis=cis_peptide,
                 variants=residue_variants,
             )
-            residues.append(residue)
+            if residue.chain_code and residue.sequence_code:
+                residues.append(residue)
 
-    return list(residues)
+    return residues
 
 
 def sequence_3let_to_res(
@@ -627,6 +834,30 @@ def get_chain_starts(residues: List[SequenceResidue]) -> Dict[str, int]:
     }
 
 
+def get_chain_ends(residues: List[SequenceResidue]) -> Dict[str, int]:
+    """
+    from a list of residues get the highest residue number for each chain ignoring any sequence codes that
+    can't be converted to an integer
+
+    :param residues:  a list of residues from one or more chains
+    :return: a dictionary of chain starts by chain_code
+    """
+
+    chain_residue_numbers = {}
+
+    for residue in residues:
+
+        if is_int(residue_number := residue.sequence_code):
+            chain_residue_numbers.setdefault(residue.chain_code, []).append(
+                residue_number
+            )
+
+    return {
+        chain_code: max(residue_numbers)
+        for chain_code, residue_numbers in chain_residue_numbers.items()
+    }
+
+
 def sequence_to_chains(residues: List[SequenceResidue]) -> List[str]:
     """
     from a list of residues get chain_codes
@@ -766,6 +997,7 @@ def get_residue_name_from_lookup(
     return residue_name
 
 
+# TODO sequence codes should be ints if they look like ints (currently fails tests)
 def sequence_to_residue_name_lookup(
     sequence: List[SequenceResidue],
 ) -> Dict[Tuple[str, int], str]:
