@@ -4,7 +4,7 @@ from fnmatch import fnmatch
 from io import StringIO
 from itertools import zip_longest
 from pathlib import Path
-from typing import IO, AnyStr, List, Optional
+from typing import IO, AnyStr, List, Optional, Tuple, Union
 
 from click.testing import Result
 from pynmrstar import Entry
@@ -14,8 +14,47 @@ from typer.testing import CliRunner
 NOQA_E501 = "# noqa: E501"
 
 
-def run_and_read_pytest(args):
+def read_test_data(file_path: str, root_directory: Optional[str] = None) -> str:
+    """
+    Reads the content of a test data file from standard locations.
 
+    This function reads the content of a test data file located at the given file path.
+    If a root directory is provided, the function will consider the file path to be relative to this directory
+    using the function path_in_test_data for lookup.
+
+    Args:
+        file_path (str): The path to the test data file.
+        root_directory (Optional[str], optional): The root directory from which the file path is considered to be
+                                                  relative.
+                                                  If None, the file path is considered to be absolute.
+
+    Returns:
+        str: The content of the test data file.
+    """
+
+    file_path = (
+        path_in_test_data(root_directory, file_path) if root_directory else file_path
+    )
+    with open(file_path) as sequence_stream:
+        sequence_stream = sequence_stream.read()
+    return sequence_stream
+
+
+def run_and_read_pytest(args: List[str]) -> Tuple[int, str, str]:
+    """
+    Runs pytest with the provided arguments and captures the output.
+
+    This function runs pytest with the given arguments and captures the return code,
+    standard output, and standard error output. It temporarily redirects sys.stdout
+    and sys.stderr to capture the output.
+
+    Args:
+        args (List[str]): The arguments to pass to pytest.
+
+    Returns:
+        Tuple[int, str, str]: the return code, standard output,
+        and standard error output from pytest.
+    """
     from pytest import main
 
     original_output = sys.stdout
@@ -125,7 +164,7 @@ def assert_lines_match(
         lines_reported = [line for line in lines_reported if len(line.strip()) != 0]
 
     zip_lines = zip_longest(lines_expected, lines_reported, fillvalue="")
-    for i, (expected_line, reported_line) in enumerate(zip_lines):
+    for i, (expected_line, reported_line) in enumerate(zip_lines, start=1):
 
         expected_line_stripped = expected_line.strip()
         reported_line_stripped = reported_line.strip()
@@ -136,19 +175,19 @@ def assert_lines_match(
 
         if reported_line_stripped != expected_line_stripped:
 
-            for line in lines_expected:
-                print(f"exp|{line}")
+            for line_no, line in enumerate(lines_expected, start=1):
+                print(f"exp|{line_no}|{line}")
             print()
 
-            for line in lines_reported:
-                print(f"rep|{line}")
+            for line_no, line in enumerate(lines_reported, start=1):
+                print(f"rep|{line_no}|{line}")
             print()
 
             print("line that caused the error:")
             print()
 
-            print(f"exp|{i}|  |{expected_line_stripped}|")
-            print(f"rep|{i}|  |{reported_line_stripped}|")
+            print(f"exp|{i}| {expected_line.strip()}|")
+            print(f"rep|{i}| {reported_line.strip()}|")
 
         assert reported_line_stripped == expected_line_stripped
 
@@ -323,3 +362,50 @@ def run_and_report(
     assert result.exit_code == expected_exit_code
 
     return result
+
+
+def assert_frame_category_exists(
+    entry: Union[Entry, str], category: str, count: int = 1, exact: bool = False
+):
+    """
+    Asserts that the specified category exists in the given entry and
+    additionally that the number of frames in that category is greater than the
+    expected count if the count is specified. If you want to use an exact count
+    set exact to True.
+
+    Args:
+        entry (Entry): The NEF entry to check.
+        category (str): The category to look for in the entry.
+        count (int, optional): The expected number of frames in the category. Defaults to 1.
+        exact (bool, optional): If True, the number of frames with the category must match the expected count exactly.
+    Raises:
+        AssertionError: If the number of frames with the category does not match the expected count.
+    """
+
+    """
+      Asserts that the specified category exists in the given entry and that the number of frames in that category
+      matches the expected count [default >1].
+
+      This function checks if the specified category exists in the given NEF entry. If the category exists, it then
+      checks if the number of frames in that category is greater than or equal to the expected count. If the 'exact'
+      parameter is set to True, the function checks if the number of frames in the category exactly matches
+      the expected count.
+
+      Args:
+          entry (Union[Entry, str]): The NEF entry to check. This can be an Entry object or a string.
+          category (str): The category to look for in the entry.
+          count (int, optional): The expected number of frames in the category. Defaults to 1.
+          exact (bool, optional): If True, the number of frames with the category must match the expected
+          count exactly. Defaults to False.
+
+      Raises:
+          AssertionError: If the number of frames with the category does not match the expected count.
+      """
+
+    if isinstance(entry, str):
+        entry = Entry.from_string(entry)
+    globals_frames = entry.get_saveframes_by_category(category)
+    if exact:
+        assert len(globals_frames) == count
+    else:
+        assert len(globals_frames) >= count
