@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# for pynmrstar to avoid WARNING:root:Loop with no data on line: xx
+
 import logging
 import sys
 from importlib import import_module
@@ -22,7 +22,7 @@ if not sys.version_info >= MINIMUM_VERSION:
     )
     print("exiting...", file=sys.stderr)
 
-
+# for pynmrstar to avoid WARNING:root:Loop with no data on line: xx
 logging.getLogger().setLevel(logging.ERROR)
 
 EXIT_ERROR = 1
@@ -83,6 +83,7 @@ def main():
             "nef_pipelines.tools.frames",
             "nef_pipelines.tools.globals",
             "nef_pipelines.tools.header",
+            "nef_pipelines.tools.loops",
             "nef_pipelines.tools.peaks",
             "nef_pipelines.tools.save",
             "nef_pipelines.tools.series",
@@ -92,6 +93,7 @@ def main():
             "nef_pipelines.tools.stream",
             "nef_pipelines.tools.test",
             "nef_pipelines.transcoders.csv",
+            "nef_pipelines.transcoders.deep",
             "nef_pipelines.transcoders.echidna",
             "nef_pipelines.transcoders.fasta",
             "nef_pipelines.transcoders.mars",
