@@ -4,6 +4,7 @@ from nef_pipelines.lib.test_lib import (
     assert_lines_match,
     isolate_frame,
     path_in_test_data,
+    read_test_data,
     run_and_report,
 )
 from nef_pipelines.transcoders.nmrview.importers.peaks import peaks
@@ -13,45 +14,29 @@ MOLECULAR_SYSTEM_NMRVIEW = "nef_spectrum_nmrview"
 app = typer.Typer()
 app.command()(peaks)
 
-EXPECTED_4AA = open(path_in_test_data(__file__, "nmrview_expected_4aa.txt")).read()
+
+EXPECTED_4AA = read_test_data("nmrview_expected_4aa.txt", __file__)
 
 
 # noinspection PyUnusedLocal
-def test_3peaks(clear_cache):
+def test_4_peaks():
     peaks_path = path_in_test_data(__file__, "4peaks.xpk")
-    sequence_path = path_in_test_data(__file__, "4peaks.seq")
 
-    args = ["--sequence", sequence_path, "--axis", "1H.1H.15N", peaks_path]
-    result = run_and_report(app, args)
+    sequence_stream = read_test_data("4peaks_seq.nef", __file__)
+
+    result = run_and_report(
+        app,
+        [
+            peaks_path,
+        ],
+        input=sequence_stream,
+    )
 
     result = isolate_frame(result.stdout, "nef_nmr_spectrum_simnoe")
 
     assert_lines_match(EXPECTED_4AA, result)
 
 
-def test_3peaks_bad_axis_codes(clear_cache):
-    # reading stdin doesn't work in pytest so for a clean header
-    # TODO move to conftest.py
-    peaks_path = path_in_test_data(__file__, "4peaks.xpk")
-    sequence_path = path_in_test_data(__file__, "4peaks.seq")
-    args = [
-        "--sequence",
-        sequence_path,
-        "--axis",
-        "1H,15N",
-        peaks_path,
-    ]
-    result = run_and_report(app, args, expected_exit_code=1)
-
-    EXPECTED = [
-        "can't find isotope code for axis 2 got axis codes 1H,15N",
-        "exiting...",
-    ]
-
-    for expected in EXPECTED:
-        assert expected in result.stdout
-
-
 EXPECTED_JOE_CLIC = """\
     save_nef_nmr_spectrum_trosyrdcjoe
         _nef_nmr_spectrum.sf_category          nef_nmr_spectrum
@@ -71,7 +56,7 @@ EXPECTED_JOE_CLIC = """\
             _nef_spectrum_dimension.is_acquisition
 
             1   ppm   1H   600.052978516    6.1679  .   circular   true   .
-            2   ppm   1H   60.8100013733   35.9997  .   circular   true   .
+            2   ppm  15N   60.8100013733   35.9997  .   circular   true   .
 
         stop_
 
@@ -103,7 +88,7 @@ EXPECTED_JOE_CLIC = """\
             _nef_peak.residue_name_2
             _nef_peak.atom_name_2
 
-            1   0   0.254054695368   .   0.0368   .   8.15968   .   126.97411   .   A   2   ala   H   A   2   ala   N
+            1   0   0.254054695368   .   0.0368   .   8.15968   .   126.97411   .   A   2   ALA   H   A   2   ALA   N
 
         stop_
 
@@ -114,16 +99,16 @@ EXPECTED_JOE_CLIC = """\
 # noinspection PyUnusedLocal
 def test_joe_bad_sweep_widths():
     peaks_path = path_in_test_data(__file__, "joe_clic.xpk")
-    sequence_path = path_in_test_data(__file__, "4peaks.seq")
 
-    command = [
-        "--sequence",
-        sequence_path,
-        "--axis",
-        "1H.1H.15N",
-        peaks_path,
-    ]
-    result = run_and_report(app, command)
+    sequence_stream = read_test_data("4peaks_seq.nef", __file__)
+
+    result = run_and_report(
+        app,
+        [
+            peaks_path,
+        ],
+        input=sequence_stream,
+    )
 
     result = isolate_frame(result.stdout, "nef_nmr_spectrum_trosyrdcjoe")
 
