@@ -3,6 +3,7 @@ import typer
 from nef_pipelines.lib.test_lib import (
     assert_lines_match,
     path_in_test_data,
+    read_test_data,
     run_and_report,
 )
 from nef_pipelines.transcoders.sparky.exporters.peaks import peaks
@@ -26,12 +27,14 @@ Assignment       w1       w2      Height  Volume
 
 """
 
+INPUT_UBI_PEAKS_SHORT_NEF = read_test_data("ubi_peaks_short.neff", __file__)
+
 
 def test_ppm_out_short():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
-
-    result = run_and_report(app, ["--file-name-template", "-"], input=STREAM)
+    result = run_and_report(
+        app, ["--file-name-template", "-"], input=INPUT_UBI_PEAKS_SHORT_NEF
+    )
 
     assert_lines_match(EXPECTED, result.stdout)
 
@@ -52,12 +55,10 @@ EXPECTED_SUPPRESS_ASSIGNMENT = """\
 
 def test_ppm_out_short_suppress_assigment():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
-
     result = run_and_report(
         app,
         ["--file-name-template", "-", "--suppress-column", "assignment"],
-        input=STREAM,
+        input=INPUT_UBI_PEAKS_SHORT_NEF,
     )
 
     assert_lines_match(EXPECTED_SUPPRESS_ASSIGNMENT, result.stdout)
@@ -80,10 +81,10 @@ Assignment       w1       w2        Volume
 
 def test_ppm_out_short_no_height():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
-
     result = run_and_report(
-        app, ["--file-name-template", "-", "--suppress-column", "height"], input=STREAM
+        app,
+        ["--file-name-template", "-", "--suppress-column", "height"],
+        input=INPUT_UBI_PEAKS_SHORT_NEF,
     )
 
     assert_lines_match(EXPECTED_NO_HEIGHT, result.stdout)
@@ -106,10 +107,10 @@ Assignment       w1       w2      Height
 
 def test_ppm_out_short_no_volume():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
-
     result = run_and_report(
-        app, ["--file-name-template", "-", "--suppress-column", "volume"], input=STREAM
+        app,
+        ["--file-name-template", "-", "--suppress-column", "volume"],
+        input=INPUT_UBI_PEAKS_SHORT_NEF,
     )
 
     assert_lines_match(EXPECTED_NO_VOLUME, result.stdout)
@@ -132,8 +133,6 @@ Assignment       w1       w2
 
 def test_ppm_out_short_no_height_or_volume():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
-
     result = run_and_report(
         app,
         [
@@ -144,7 +143,7 @@ def test_ppm_out_short_no_height_or_volume():
             "--suppress-column",
             "height",
         ],
-        input=STREAM,
+        input=INPUT_UBI_PEAKS_SHORT_NEF,
     )
 
     assert_lines_match(EXPECTED_NO_HEIGHT_OR_VOLUME, result.stdout)
@@ -152,8 +151,6 @@ def test_ppm_out_short_no_height_or_volume():
 
 def test_ppm_out_short_no_height_or_volume_with_data():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
-
     result = run_and_report(
         app,
         [
@@ -163,7 +160,7 @@ def test_ppm_out_short_no_height_or_volume_with_data():
             "volume,height",
             "--add-data",
         ],
-        input=STREAM,
+        input=INPUT_UBI_PEAKS_SHORT_NEF,
     )
 
     assert_lines_match(EXPECTED_NO_HEIGHT_OR_VOLUME, result.stdout)
@@ -184,9 +181,9 @@ PR_66H-HA        7.406   4.180          10       5
 
 def test_ppm_out_short_different_residues():
 
-    STREAM = open(
-        path_in_test_data(__file__, "ubi_peaks_short_different_residues.neff")
-    ).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short_different_residues.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(app, ["--file-name-template", "-"], input=STREAM)
 
@@ -207,7 +204,9 @@ A.G66H-A.G67HA   7.906   4.380          14       9
 
 def test_ppm_out_short_chains():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short_chains.neff")).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short_chains.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(app, ["--file-name-template", "-"], input=STREAM)
 
@@ -228,7 +227,9 @@ G66H-G67HA      7.906    4.380          14       9
 
 def test_ppm_out_short_no_chains():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short_chains.neff")).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short_chains.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app, ["--file-name-template", "-", "--no-chains"], input=STREAM
@@ -254,7 +255,9 @@ Assignment       w1       w2      Data  Height  Volume
 
 def test_ppm_out_short_with_data():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app, ["--file-name-template", "-", "--add-data"], input=STREAM
@@ -280,7 +283,9 @@ Assignment       w1       w2      Height  Volume
 
 def test_ppm_out_short_full_assignments():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app, ["--file-name-template", "-", "--full-assignments"], input=STREAM
@@ -306,7 +311,9 @@ Assignment       w1     w2   Height  Volume
 
 def test_ppm_out_short_discard_assignments():
 
-    STREAM = open(path_in_test_data(__file__, "ubi_peaks_short.neff")).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app, ["--file-name-template", "-", "--discard-assignments"], input=STREAM
@@ -333,9 +340,9 @@ Assignment       w1       w2      Height  Volume
 
 def test_ppm_out_short_with_full_assignments():
 
-    STREAM = open(
-        path_in_test_data(__file__, "peaks_short_with_assignments.neff")
-    ).read()
+    file_name = path_in_test_data(__file__, "peaks_short_with_assignments.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(app, ["--file-name-template", "-"], input=STREAM)
 
@@ -360,9 +367,9 @@ Assignment       w1       w2      Height  Volume
 
 def test_ppm_out_short_with_different_chain_separator():
 
-    STREAM = open(
-        path_in_test_data(__file__, "peaks_short_with_assignments.neff")
-    ).read()
+    file_name = path_in_test_data(__file__, "peaks_short_with_assignments.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app, ["--file-name-template", "-", "--chain-separator", "_"], input=STREAM
@@ -389,9 +396,9 @@ Assignment                     w1       w2       w3      Height  Volume
 
 def test_ppm_out_short_3d_m1():
 
-    STREAM = open(
-        path_in_test_data(__file__, "ubi_peaks_short_i_minus_one.neff")
-    ).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short_i_minus_one.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app,
@@ -423,9 +430,9 @@ Assignment                      w1      w2       w3     Height  Volume
 
 def test_ppm_out_short_3d_m1_no_negatives():
 
-    STREAM = open(
-        path_in_test_data(__file__, "ubi_peaks_short_i_minus_one.neff")
-    ).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short_i_minus_one.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(
         app, ["--file-name-template", "-", "--no-negative-residues"], input=STREAM
@@ -436,9 +443,9 @@ def test_ppm_out_short_3d_m1_no_negatives():
 
 def test_ppm_out_short_overlapped_chains():
 
-    STREAM = open(
-        path_in_test_data(__file__, "ubi_peaks_short_overlapping_chains.neff")
-    ).read()
+    file_name = path_in_test_data(__file__, "ubi_peaks_short_overlapping_chains.neff")
+    with open(file_name) as fh:
+        STREAM = fh.read()
 
     result = run_and_report(app, ["--no-chains"], input=STREAM, expected_exit_code=1)
 
