@@ -18,16 +18,17 @@ def test_2_dihedrals():
     sequence_path = path_in_test_data(__file__, "3a_ab.neff")
     dihedrals_path = path_in_test_data(__file__, "test_2_dihedrals.tbl")
 
-    nef_sequence = open(sequence_path, "r").read()
+    with open(sequence_path, "r") as fh:
+        nef_sequence = fh.read()
 
     args = [dihedrals_path]
     result = run_and_report(app, args, input=nef_sequence)
 
     EXPECTED = """\
         save_nef_dihedral_restraint_list_test_2_dihedrals                               # noqa: E501
-            _nef_dihedral_restraint.sf_category     nef_dihedral_restraint_list
-            _nef_dihedral_restraint.sf_framecode    nef_dihedral_restraint_list_test_2_dihedrals
-            _nef_dihedral_restraint.potential_type  undefined
+            _nef_dihedral_restraint_list.sf_category     nef_dihedral_restraint_list
+            _nef_dihedral_restraint_list.sf_framecode    nef_dihedral_restraint_list_test_2_dihedrals
+            _nef_dihedral_restraint_list.potential_type  undefined
 
             loop_
                 _nef_dihedral_restraint.index
@@ -74,7 +75,8 @@ def test_2_dihedrals_bad():
     sequence_path = path_in_test_data(__file__, "3a_ab.neff")
     dihedrals_path = path_in_test_data(__file__, "test_2_dihedrals_bad.tbl")
 
-    nef_sequence = open(sequence_path, "r").read()
+    with open(sequence_path, "r") as fh:
+        nef_sequence = fh.read()
 
     args = [dihedrals_path]
     result = run_and_report(app, args, input=nef_sequence, expected_exit_code=1)
@@ -87,16 +89,17 @@ def test_2_dihedrals_no_segids():
     sequence_path = path_in_test_data(__file__, "3a_ab.neff")
     dihedrals_path = path_in_test_data(__file__, "test_2_dihedrals_no_segids.tbl")
 
-    nef_sequence = open(sequence_path, "r").read()
+    with open(sequence_path, "r") as fh:
+        nef_sequence = fh.read()
 
     args = [dihedrals_path, "--chains", "AAAA"]
     result = run_and_report(app, args, input=nef_sequence)
 
     EXPECTED = """\
         save_nef_dihedral_restraint_list_test_2_dihedrals_no_segids                              # noqa: E501
-            _nef_dihedral_restraint.sf_category     nef_dihedral_restraint_list
-            _nef_dihedral_restraint.sf_framecode    nef_dihedral_restraint_list_test_2_dihedrals_no_segids
-            _nef_dihedral_restraint.potential_type  undefined
+            _nef_dihedral_restraint_list.sf_category     nef_dihedral_restraint_list
+            _nef_dihedral_restraint_list.sf_framecode    nef_dihedral_restraint_list_test_2_dihedrals_no_segids
+            _nef_dihedral_restraint_list.potential_type  undefined
 
             loop_
                 _nef_dihedral_restraint.index
@@ -143,16 +146,17 @@ def test_2_dihedrals_overriding_segids():
     sequence_path = path_in_test_data(__file__, "3a_ab.neff")
     dihedrals_path = path_in_test_data(__file__, "test_2_dihedrals.tbl")
 
-    nef_sequence = open(sequence_path, "r").read()
+    with open(sequence_path, "r") as fh:
+        nef_sequence = fh.read()
 
     args = [dihedrals_path, "--chains", "BBBB", "--use-chains"]
     result = run_and_report(app, args, input=nef_sequence)
 
     EXPECTED = """\
         save_nef_dihedral_restraint_list_test_2_dihedrals                                     # noqa: E501
-            _nef_dihedral_restraint.sf_category     nef_dihedral_restraint_list
-            _nef_dihedral_restraint.sf_framecode    nef_dihedral_restraint_list_test_2_dihedrals
-            _nef_dihedral_restraint.potential_type  undefined
+            _nef_dihedral_restraint_list.sf_category     nef_dihedral_restraint_list
+            _nef_dihedral_restraint_list.sf_framecode    nef_dihedral_restraint_list_test_2_dihedrals
+            _nef_dihedral_restraint_list.potential_type  undefined
 
             loop_
                 _nef_dihedral_restraint.index
