@@ -9,7 +9,7 @@ if nef_app.app:
     nef_app.app.add_typer(
         frames_app,
         name="frames",
-        help="-  carry out operations on frames in nef frames",
+        help="- carry out operations on frames in nef files",
     )
 
     # import of specific importers must be after app creation to avoid circular imports
