@@ -12,7 +12,7 @@ from nef_pipelines.lib.nef_lib import (
 from nef_pipelines.lib.sequence_lib import (
     TRANSLATIONS_3_1_PROTEIN,
     BadResidue,
-    chain_code_iter,
+    get_chain_code_iter,
     get_residue_name_from_lookup,
     translate_1_to_3,
 )
@@ -26,7 +26,6 @@ from nef_pipelines.lib.structures import (
 )
 from nef_pipelines.lib.util import (
     STDIN,
-    cached_file_stream,
     exit_error,
     is_float,
     is_int,
@@ -106,7 +105,7 @@ def shifts(
         ..., help="input files of type mars shifts.tab", metavar="<MARS-shifts>.tab"
     ),
 ):
-    """convert MARS shift file <mars-shifts>.txt to NEF"""
+    """- import shifts from MARS input shift file <mars-shifts>.tab"""
 
     entry = read_or_create_entry_exit_error_on_bad_file(input, entry_name)
 
@@ -126,9 +125,10 @@ def pipe(
 
     sparky_frames = []
 
-    for file_name, chain_code in zip(file_names, chain_code_iter(chain_codes)):
+    chain_code_iter = get_chain_code_iter(chain_codes)
+    for file_name, chain_code in zip(file_names, chain_code_iter):
 
-        with cached_file_stream(file_name) as lines:
+        with open(file_name) as lines:
 
             sparky_shifts = _parse_shifts(
                 lines,
@@ -235,6 +235,21 @@ def _get_residues_from_string(string):
     return result
 
 
+# TODO: remove when python 3.8 no longer supported
+def _removeprefix(target: str, prefix: str) -> str:
+    if target.startswith(prefix):
+        return target[len(prefix) :]
+    else:
+        return target
+
+
+def _removesuffix(target: str, suffix: str) -> str:
+    if target.endswith(suffix):
+        return target[: -len(suffix)]
+    else:
+        return target
+
+
 def _parse_line(
     line_info, heading_indices, chain_code, prefix_to_strip, parse_residues
 ):
@@ -252,7 +267,7 @@ def _parse_line(
 
                 value = float(value)
 
-                pseudo_residue = pseudo_residue.removeprefix(prefix_to_strip)
+                pseudo_residue = _removeprefix(pseudo_residue, prefix_to_strip)
 
                 (
                     pseudo_pre_chars,
@@ -291,7 +306,7 @@ def _split_heading(heading: str):
 
     offset = ""
     if heading.endswith("-1"):
-        heading = heading.removesuffix("-1")
+        heading = _removesuffix(heading, "-1")
         offset = "-1"
     return heading, offset
 
@@ -312,9 +327,9 @@ def _warn_multiple_residues(residue_names, line_info):
 
 def _split_pseudo_residue(pseudo_residue):
     first_characters = _get_starting_alpha(pseudo_residue)
-    pseudo_residue = pseudo_residue.removeprefix(first_characters)
+    pseudo_residue = _removeprefix(pseudo_residue, first_characters)
     numbers = get_starting_number(pseudo_residue)
-    last_characters = pseudo_residue.removeprefix(numbers)
+    last_characters = _removeprefix(pseudo_residue, numbers)
 
     return first_characters, numbers, last_characters
 
